@@ -1,5 +1,5 @@
 package Bot::Backbone::Service::SlackChat;
-$Bot::Backbone::Service::SlackChat::VERSION = '0.160490';
+$Bot::Backbone::Service::SlackChat::VERSION = '0.161740';
 use v5.14;
 use Bot::Backbone::Service;
 
@@ -13,6 +13,7 @@ with qw(
 use Bot::Backbone::Message;
 use Carp;
 use CHI;
+use Encode;
 use AnyEvent::SlackRTM;
 use WebService::Slack::WebApi;
 
@@ -367,9 +368,10 @@ sub got_group_message {
 sub send_message {
     my ($self, $params) = @_;
 
-    my $to    = $params->{to};
-    my $group = $params->{group};
-    my $text  = $params->{text};
+    my $to          = $params->{to};
+    my $group       = $params->{group};
+    my $text        = $params->{text};
+    my $attachments = $params->{attachments};
 
     my $channel;
     if (defined $group) {
@@ -379,11 +381,18 @@ sub send_message {
         $channel = $self->load_user_channel( user => $to );
     }
 
-    $self->api->chat->post_message(
+    my %message_opts = (
         channel => $channel,
-        text    => $text,
         as_user => 1,
     );
+    if (defined $text) {
+        $message_opts{text} = encode('utf8', $text);
+    }
+    if (defined $attachments) {
+        $message_opts{attachments} = $attachments;
+    }
+
+    $self->api->chat->post_message(%message_opts);
 }
 
 
@@ -401,7 +410,7 @@ Bot::Backbone::Service::SlackChat - Connect and chat with a Slack server
 
 =head1 VERSION
 
-version 0.160490
+version 0.161740
 
 =head1 SYNOPSIS
 
@@ -547,12 +556,15 @@ This handles message received from private group or team channels.
 =head2 send_message
 
     method send_message({
-        to    => $user_id,
-        group => $group_id,
-        text  => $message,
+        to          => $user_id,
+        group       => $group_id,
+        text        => $message,
+        attachments => $attachments,
     })
 
-This sends a message to a Slack channel. To the named user's IM channel or to a private group or team channel named by C<$group_id>.
+This sends a message to a Slack channel. To the named user's IM channel or to a private group or team channel named by C<$group_id>.  Attachments can be included to produce formatted messages.
+
+L<Slack Message Attachment API|https://api.slack.com/docs/attachments>
 
 =for Pod::Coverage     load_channel
     mark_read
